==> baseui-5.5.0.tgz: package/es/pagination/stateful-pagination.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import Pagination from './pagination.js';
import StatefulContainer from './stateful-container.js';
export default function StatefulPagination(_ref) {
  var numPages = _ref.numPages,
      initialState = _ref.initialState,
      stateReducer = _ref.stateReducer,
      onPageChange = _ref.onPageChange,
      props = _objectWithoutProperties(_ref, ["numPages", "initialState", "stateReducer", "onPageChange"]);

  return React.createElement(StatefulContainer, {
    numPages: numPages,
    initialState: initialState,
    stateReducer: stateReducer,
    onPageChange: onPageChange
  }, function (renderProps) {
    return React.createElement(Pagination, _extends({
      numPages: numPages
    }, renderProps, props));
  });
}
StatefulPagination.defaultProps = _objectSpread({}, StatefulContainer.defaultProps, Pagination.defaultProps);

==> baseui-6.0.1.tgz: package/es/pagination/stateful-pagination.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import Pagination from './pagination.js';
import StatefulContainer from './stateful-container.js';
export default function StatefulPagination(_ref) {
  var numPages = _ref.numPages,
      initialState = _ref.initialState,
      stateReducer = _ref.stateReducer,
      onPageChange = _ref.onPageChange,
      props = _objectWithoutProperties(_ref, ["numPages", "initialState", "stateReducer", "onPageChange"]);

  return React.createElement(StatefulContainer, {
    numPages: numPages,
    initialState: initialState,
    stateReducer: stateReducer,
    onPageChange: onPageChange
  }, function (renderProps) {
    return React.createElement(Pagination, _extends({
      numPages: numPages
    }, renderProps, props));
  });
}
StatefulPagination.defaultProps = {
  initialState: {
    currentPage: 1
  },
  stateReducer: function stateReducer(changeType, changes) {
    return changes;
  },
  labels: {
    prevButton: 'Prev',
    nextButton: 'Next',
    preposition: 'of'
  },
  overrides: {}
};
